@@ -12,13 +12,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from datetime import datetime
+
 __author__ = "Vitaliy Zakaznikov"
-__version__ = "1.9.220515.1003036"
+__version__ = "1.9.220524.1140201"
 __repository__ = "https://github.com/testflows/TestFlows-Core.git"
-__commit__ = "2f1abe3b47290bc8ea1f81def801a1d8aed59cd7"
+__commit__ = "2ce3cf5d18b5282753ccc35679e46ff76d4d4218"
 __branch__ = "master"
 __license__ = f"""
-Copyright 2019-2021 Katteli Inc.
+Copyright 2019-{datetime.now().year} Katteli Inc.
 TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
 
 Licensed under the Apache License, Version 2.0 (the "License");
@@ -31,5 +33,7 @@ Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
-limitations under the License
+limitations under the License.
+
+See testflows/_core/contrib folder in sources for lincenses of each third-party module.
 """
