@@ -78,6 +78,10 @@ PAUSE_ON_PASS = 1 << 37
 PAUSE_ON_FAIL = 1 << 38
 # remote test
 REMOTE = 1 << 39
+# setup
+SETUP = 1 << 40
+# cleanup
+CLEANUP = 1 << 41
 # expected result
 ERESULT = EOK | EFAIL | ESKIP | EERROR
 # expected any result
@@ -88,7 +92,7 @@ XRESULT = XOK | XFAIL | XERROR | XNULL
 NOT_COUNTED = FAIL_NOT_COUNTED
 NOT_COUNTED_ANY = FAIL_NOT_COUNTED | ERROR_NOT_COUNTED | NULL_NOT_COUNTED
 # cumulative flags
-CFLAGS = UT | MANDATORY | MANUAL | PARALLEL | NO_PARALLEL | NOT_REPEATABLE | RETRIED
+CFLAGS = UT | MANDATORY | MANUAL | PARALLEL | NO_PARALLEL | NOT_REPEATABLE | RETRIED | SETUP | CLEANUP
 
 class Flags(object):
     """Test flags."""
@@ -99,7 +103,7 @@ class Flags(object):
             PAUSE_BEFORE, PAUSE_AFTER, MANUAL, AUTO,
             REPORT, DOCUMENT, MANDATORY, PARALLEL, NO_PARALLEL, CLEAR,
             ASYNC, REPEATED, NOT_REPEATABLE, RETRIED, LAST_RETRY,
-            PAUSE_ON_PASS, PAUSE_ON_FAIL, REMOTE
+            PAUSE_ON_PASS, PAUSE_ON_FAIL, REMOTE, SETUP, CLEANUP
         ]
     all_str = [
             "TE", "UT", "SKIP", "EOK", "EFAIL", "EERROR", "ESKIP",
@@ -108,7 +112,7 @@ class Flags(object):
             "PAUSE_BEFORE", "PAUSE_AFTER", "MANUAL", "AUTO",
             "REPORT", "DOCUMENT", "MANDATORY", "PARALLEL", "NO_PARALLEL", "CLEAR",
             "ASYNC", "REPEATED", "NOT_REPEATABLE", "RETRIED", "LAST_RETRY",
-            "PAUSE_ON_PASS", "PAUSE_ON_FAIL", "REMOTE"
+            "PAUSE_ON_PASS", "PAUSE_ON_FAIL", "REMOTE", "SETUP", "CLEANUP"
         ]
 
     def __init__(self, flags=0):
