@@ -40,7 +40,7 @@ from ..asyncio import is_running_in_event_loop, wrap_future
 from ..service import BaseServiceObject, ServiceObjectType, process_service, auto_expose
 from .. import current, top, previous, _get_parallel_context, join as parallel_join
 from ...objects import Result
-from ...exceptions import TerminatedError
+from ...tracing import logging
 
 _shutdown = False
 _worker_pids = {}
@@ -109,6 +109,7 @@ class WorkerSettings:
             ) if settings.global_async_pool is not None else None
         self.global_process_pool = self._set_service_object(settings.global_process_pool)
         self.secrets_registry = settings.secrets_registry
+        self.trace = settings.trace
 
     def _set_service_object(self, obj):
         if obj is None:
@@ -170,6 +171,8 @@ class _WorkItem(object):
             # set shared global process pool
             settings.global_process_pool = work_settings.global_process_pool
             settings.secrets_registry = work_settings.secrets_registry
+            # trace
+            settings.trace = work_settings.trace
 
         def runner(self):
             try:
@@ -339,6 +342,7 @@ class ProcessPoolExecutor(_base.Executor):
         if num_procs < self._max_workers:
             command = ["tfs-worker",
                 "--oid", str(self._work_queue.oid),
+                "--identity", str(self._work_queue.identity.hex()),
                 "--hostname", str(self._work_queue.address.hostname),
                 "--port", str(self._work_queue.address.port)
             ]
@@ -347,6 +351,9 @@ class ProcessPoolExecutor(_base.Executor):
                 command.append("--debug")
             if settings.no_colors:
                 command.append("--no-colors")
+            if settings.trace:
+                command.append("--trace")
+                command.append(f"{logging.getLevelName(settings.trace).lower()}")
 
             loop = process_service().loop
 
@@ -381,7 +388,7 @@ class ProcessPoolExecutor(_base.Executor):
             try:
                 if test:
                     if self._join_on_shutdown:
-                        parallel_join(no_async=True, test=test, filter=lambda future: hasattr(future, "_executor_uid") and future._executor_uid == self._uid)
+                        parallel_join(no_async=True, test=test, filter=lambda future: hasattr(future, "_executor_uid") and future._executor_uid == self._uid, cancel_pending=True)
             finally:
                 for proc in self._processes:
                     while is_running(proc.transport.get_pid()):
